Chapter: Optional
=================

This chapter contains optional tutorials expanding on different aspects of how **PyAutoLens** work.

The chapter contains the following tutorials:

`Tutorial: Sub-grids  <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_optional/tutorial_sub_grids.ipynb>`_
- Use sub-grids to perform more accuratee and precise lensing calculations.

`Tutorial: Searches  <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_optional/tutorial_searches.ipynb>`_
- Alternative non-linear searches to sample parameter space.

